@@ -36,22 +36,15 @@ KicApp::KicApp(int &argc, char **argv)
     : QApplication(argc, argv)
 {
     QApplication::setApplicationDisplayName(i18n("KDE Info Center"));
-    QApplication::setOrganizationDomain("kde.org");
-    display = new KInfoCenter();
-    display->show();
+    QApplication::setOrganizationDomain(QStringLiteral("kde.org"));
 
-    KDBusService* service = new KDBusService(KDBusService::Unique, this);
-}
-
-int main(int argc, char *argv[])
-{
     KLocalizedString::setApplicationDomain("kinfocenter");
 
     KAboutData aboutData( QStringLiteral("kinfocenter"), i18n("KDE Info Center"),
         PROJECT_VERSION, i18n("The KDE Info Center"), KAboutLicense::GPL,
         i18n("(c) 2009-2010, The KDE SC KInfocenter Development Team"));
 
-    aboutData.setProgramIconName("hwinfo");
+    aboutData.setProgramIconName(QStringLiteral("hwinfo"));
     aboutData.addAuthor(i18n("David Hubner"),i18n("Current Maintainer"), QStringLiteral("hubnerd@ntlworld.com"));
     aboutData.addAuthor(i18n("Helge Deller"), i18n("Previous Maintainer"), QStringLiteral("deller@kde.org"));
     aboutData.addAuthor(i18n("Matthias Hoelzer-Kluepfel"),QString(), QStringLiteral("hoelzer@kde.org"));
@@ -60,14 +53,23 @@ int main(int argc, char *argv[])
     aboutData.addAuthor(i18n("Waldo Bastian"), QString(), QStringLiteral("bastian@kde.org"));
     aboutData.addAuthor(i18n("Nicolas Ternisien"), QString(), QStringLiteral("nicolas.ternisien@gmail.com"));
     KAboutData::setApplicationData(aboutData);
-    KicApp Kic(argc, argv);
 
     QCommandLineParser parser;
     parser.addHelpOption();
     parser.addVersionOption();
     aboutData.setupCommandLine(&parser);
-    parser.process(Kic);
+    parser.process(*this);
     aboutData.processCommandLine(&parser);
 
+    display = new KInfoCenter();
+    display->show();
+
+    KDBusService* service = new KDBusService(KDBusService::Unique, this);
+}
+
+int main(int argc, char *argv[])
+{
+    KicApp Kic(argc, argv);
+
     return Kic.exec();
 }
